@@ -1,2 +1,2 @@
 from .adguard import AdGuardCredentialSet, AdGuardClientDevice
-from .eero import EeroClientDevice
+from .eero import EeroClientDevice, EeroNetworkDevice
